@@ -23,6 +23,18 @@ class IRepository:
         repository._set_client_id(client_id)
         return repository
 
+    def get_client_id(self) -> ClientId:
+        if not hasattr(self, "client_id"):
+            name = self.info().get("name")
+            raise AttributeError(
+                f"{name} needs client_id. Please, {name}.use with_client_id() to get a valid"
+            )
+        return self.client_id
+
+    def get_client_id_value(self) -> str:
+        client_id = self.get_client_id()
+        return client_id.value
+
     @abstractmethod
     def save(self, *args, **kwargs) -> Result:
         return NotImplementedMethodError
